# coding: utf-8

"""
Code generated by OpenAPI Generator (https://openapi-generator.tech), manual changes will be lost - read more on https://github.com/algolia/api-clients-automation. DO NOT EDIT.
"""

from __future__ import annotations

from json import loads
from typing import Any, Dict, List, Self

from pydantic import BaseModel, ConfigDict

from algoliasearch.ingestion.models.pagination import Pagination
from algoliasearch.ingestion.models.run import Run
from algoliasearch.ingestion.models.window import Window


class RunListResponse(BaseModel):
    """
    RunListResponse
    """

    runs: List[Run]
    pagination: Pagination
    window: Window

    model_config = ConfigDict(
        use_enum_values=True, populate_by_name=True, validate_assignment=True
    )

    def to_json(self) -> str:
        return self.model_dump_json(by_alias=True, exclude_unset=True)

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RunListResponse from a JSON string"""
        return cls.from_dict(loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={},
            exclude_none=True,
        )
        _items = []
        if self.runs:
            for _item in self.runs:
                if _item:
                    _items.append(_item.to_dict())
            _dict["runs"] = _items
        if self.pagination:
            _dict["pagination"] = self.pagination.to_dict()
        if self.window:
            _dict["window"] = self.window.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of RunListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "runs": (
                    [Run.from_dict(_item) for _item in obj.get("runs")]
                    if obj.get("runs") is not None
                    else None
                ),
                "pagination": (
                    Pagination.from_dict(obj.get("pagination"))
                    if obj.get("pagination") is not None
                    else None
                ),
                "window": (
                    Window.from_dict(obj.get("window"))
                    if obj.get("window") is not None
                    else None
                ),
            }
        )
        return _obj
